#!/bin/bash -e

APP_TYPE="$1" # shell or python
SCRIPTS_DIR=$(cd "$(dirname "$0")" && pwd) || exit
PROJECT_HOME="$SCRIPTS_DIR/.."
ARCH=$(jq -r .arch "$PROJECT_HOME/info.json") || exit
DEV_FILES_DIR="$PROJECT_HOME/container_$ARCH/dev"
RESOURCES_DIR="$DEV_FILES_DIR/resources"
IMAGE_NAME="${APP_TYPE}_app_dev_image"
DESC_FILE="$DEV_FILES_DIR/${IMAGE_NAME}.desc"
SSH_DIR="$PROJECT_HOME/config/ssh"

gen_swu() {
    version=1

    if [ -e "$DESC_FILE" ]; then
        version=$(awk -F= '$1 == "swdesc_option version" { print $2 + 1 }' "$DESC_FILE")
        mv -f "$DESC_FILE" "$DESC_FILE".old
    fi
    cat > "$DESC_FILE" <<EODESC
swdesc_option version=${version:-1}

swdesc_files --extra-os root
swdesc_embed_container "${IMAGE_NAME}.tar"
EODESC

    mkswu "$DESC_FILE"
}

if [[ ! -e "$SSH_DIR/id_rsa.pub" ]]; then
    echo "id_rsa.pub not found." >&2
    echo "Please do [Terminal]->[Run Tasks...]->[Setup envronment] first on the VSCode menu." >&2
    exit 1
fi

cat "$SSH_DIR/id_rsa.pub" > "$RESOURCES_DIR/root/.ssh/authorized_keys"

"$SCRIPTS_DIR"/build_container_image.sh "$APP_TYPE" dev

gen_swu
